Class: RubyGaurden::Bed
- Inherits:
-
Object
- Object
- RubyGaurden::Bed
- Includes:
- Bindings, Bridging, Execution, RuntimeEnvironment, ThreadSafety
- Defined in:
- lib/ruby_gaurden/bed.rb
Constant Summary
Constants included from RuntimeEnvironment
RuntimeEnvironment::MAX_CACHE_SIZE
Constants included from Execution
Execution::DEFAULT_MAXIMUM_EXECUTION_TIME, Execution::DEFAULT_MAX_MEMORY
Class Method Summary collapse
-
.execute ⇒ Object
Creates a new instance of the Bed and executes the provided source.
Methods included from ThreadSafety
#execute, #maximum_execution_time, #monitor, #synchronize
Methods included from Bridging
#call, #reset_io!, #stderr, #stdout
Methods included from Bindings
Methods included from RuntimeEnvironment
#compile_and_cache, #execute, #prune_cache!
Methods included from Execution
#context, #maximum_execution_time, #maximum_execution_time_ms, #maximum_memory
Class Method Details
.execute ⇒ Object
Creates a new instance of the Bed and executes the provided source.
17 18 19 |
# File 'lib/ruby_gaurden/bed.rb', line 17 def self.execute(...) new.execute(...) end |